%
% FUNCTION 8.4 : "cp0801_PPMcorrmask"
%
% Evaluates the correlation mask ('mask') in the
% case of binary PPM UWB signals.
% 'ref' is the reference signal (with no modulation)
% which is produced by the 2PPM+TH transmitter
% 'fc' is the sampling frequency
% 'numpulses' is the number of transmitted pulses
% 'dPPM' is the value of the PPM shift
%
% Programmed by Guerino Giancola
%

function [mask00, mask11] = cp0801_PPMcorrmask_rake2(ref,fc,numpulses,dPPM,rake)

% ---------------------------------------------
% Step One - Evaluation of the correlation mask
% ---------------------------------------------

dt = 1 / fc;
LR = length(ref);
% Energy normalization
Epulse = (sum((abs(ref).^2).*dt))/numpulses;
ref = ref./sqrt(Epulse);

% Mask construction
PPMsamples = floor (dPPM ./ dt);  
sref(1:PPMsamples)=ref(length(ref)- ...
   PPMsamples+1:length(ref));
sref(PPMsamples+1:length(ref)) = ref(1:length(ref)- ...
   PPMsamples);
mask0=ref;
mask1=sref;

mask0 = conv(ref,rake);
mask0 = mask0(1:LR);
mask00=conj(mask0);

mask1=conv(sref,rake);
mask1 = mask1(1:LR);
mask11=conj(mask1);